// import parseTime, formatTime and set to filter
export { parseTime, formatTime } from '@/utils'

/**
 * Show plural label if time is plural number
 * @param {number} time
 * @param {string} label
 * @return {string}
 */
function pluralize(time, label) {
  if (time === 1) {
    return time + label
  }
  return time + label + 's'
}

/**
 * @param {number} time
 */
export function timeAgo(time) {
  const between = Date.now() / 1000 - Number(time)
  if (between < 3600) {
    return pluralize(~~(between / 60), ' minute')
  } else if (between < 86400) {
    return pluralize(~~(between / 3600), ' hour')
  } else {
    return pluralize(~~(between / 86400), ' day')
  }
}

/**
 * Number formatting
 * like 10000 => 10k
 * @param {number} num
 * @param {number} digits
 */
export function numberFormatter(num, digits) {
  const si = [
    { value: 1E18, symbol: 'E' },
    { value: 1E15, symbol: 'P' },
    { value: 1E12, symbol: 'T' },
    { value: 1E9, symbol: 'G' },
    { value: 1E6, symbol: 'M' },
    { value: 1E3, symbol: 'k' }
  ]
  for (let i = 0; i < si.length; i++) {
    if (num >= si[i].value) {
      return (num / si[i].value).toFixed(digits).replace(/\.0+$|(\.[0-9]*[1-9])0+$/, '$1') + si[i].symbol
    }
  }
  return num.toString()
}

/**
 * 10000 => "10,000"
 * @param {number} num
 */
export function toThousandFilter(num) {
  return (+num || 0).toString().replace(/^-?\d+/g, m => m.replace(/(?=(?!\b)(\d{3})+$)/g, ','))
}

/**
 * Upper case first char
 * @param {String} string
 */
export function uppercaseFirst(string) {
  return string.charAt(0).toUpperCase() + string.slice(1)
}

export function numDot(num) {
  return (num + '').replace(/(?=(\B)(\d{3})+$)/g, ',')
}

export function getTimeString(time) {
  const date = new Date(time)
  const addzero = num => (num + '').length === 1 ? '0' + num : num
  return `${date.getFullYear()}-${addzero(date.getMonth() + 1)}-${addzero(date.getDate())}  ${addzero(date.getHours())} : ${addzero(date.getMinutes())}`
}

export function scoreType(type) {
  type = +type
  if (type === 1) {
    return '销售学分'
  } else if (type === 2) {
    return '奖励学分'
  } else if (type === 3) {
    return '调整学分'
  }
  return ''
}

export function gloryType(type) {
  type = +type
  if (type === 1) {
    return '大学毕业'
  } else if (type === 2) {
    return '学士学位'
  } else if (type === 3) {
    return '硕士学位'
  } else if (type === 4) {
    return '博士学位'
  } else if (type === 5) {
    return '学霸'
  } else if (type === 0 || type === 6) {
    return '结业'
  }
  return ''
}
