import store from './store' // 引入vuex
import router from './router' // 引入vue-router
import 'nprogress/nprogress.css' // 进度条样式
import NProgress from 'nprogress' // 进度条
import { Message } from 'element-ui' // element-ui消息提示框
import { getToken } from '@/utils/auth' // 从 ckkoie 获取 token 方法
import defaultSettings from '@/settings' // 项目默认设置
NProgress.configure({ showSpinner: false }) // // 进度条配置，不要加载时的圈圈

router.beforeEach(async(to, from, next) => { // 全局导航守卫
  NProgress.start() // 进度条开始移动
  document.title = to.meta.title ? `${defaultSettings.title}-${to.meta.title}` : `${defaultSettings.title}` // 设置页面title
  if (to.path === '/1' || to.path === '/2' || to.path === '/3' || to.path === '/4') {
    next()
    return
  }
  if (getToken()) { // 当 cookie 中有 token （即用户已经登录）
    if (to.path === '/login') { // 如果 to.path 为 login 页面，则跳转到本页
      next({ path: '/' })
    } else { // 如果 to.path 为其他页面，则进行下一步判断
      if (store.getters.routes && store.getters.routes.length > 0) { // 如果 vuex 中有路由表
        next() // 直接进入该页面
      } else { // vuex 中没有路由表，表示用户刷新了页面，这时要重新获取路由表
        try {
          const { routes } = await store.dispatch('user/getInfo')
          const accessRoutes = await store.dispatch('permission/generateRoutes', routes)
          router.addRoutes(accessRoutes)
          next({ ...to, replace: true })
        } catch (error) {
          await store.dispatch('user/resetToken')
          Message.error(error || 'Has Error')
          next(`/login?redirect=${to.path}`)
          NProgress.done()
        }
      }
    }
  } else { // 如果 cookie 中是没有 token （即用户未登录）
    if (to.path === '/login') { // to.path 在路由白名单中
      next()
    } else { // to.path 不在路由白名单中，跳转到 login 页面，并将 to.path 作为参数传过去
      next(`/login?redirect=${to.path}`)
      // next(`/login`)
      NProgress.done()
    }
  }
})

router.afterEach(() => {
  NProgress.done() // 进度条结束移动
})
