import { team_all } from '@/api/teammanage'
import { login, getInfo } from '@/api/user'
import { getToken, setToken, removeToken } from '@/utils/auth'
import router, { resetRouter } from '@/router'
import { numberToChinese } from '@/utils/numToZH'

const state = {
  BP: [],
  name: '',
  avatar: '',
  routes: [],
  team_list: [],
  season_list: [],
  token: getToken()

}

const mutations = {
  SET_BP(state, BP) {
    state.BP = BP
  },
  SET_TOKEN: (state, token) => {
    state.token = token
  },
  SET_NAME: (state, name) => {
    state.name = name
  },
  SET_AVATAR: (state, avatar) => {
    state.avatar = avatar
  },
  SET_TEAM_LIST: (state, team_list) => {
    state.team_list = team_list
  },
  SET_SEASON_LIST: (state, season_list) => {
    state.season_list = season_list
  },
  SET_ROUTES: (state, routes) => {
    state.routes = routes
  }
}

const actions = {
  login({ commit }, userInfo) { // 登录
    const { username, password } = userInfo // 获取用户名和密码
    return new Promise((resolve, reject) => {
      login({ username: username.trim(), password: password }).then(response => {
        const { data } = response
        commit('SET_TOKEN', data.token)
        setToken(data.token)
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },
  getInfo({ commit, state }) { // 获取用户信息
    return new Promise((resolve, reject) => {
      getInfo(state.token).then(response => { // 获取用户基本信息和路由信息
        const { data } = response
        if (!data) {
          reject('token过期，请重新登录')
        }
        data.routes = JSON.parse(data.routes) // 将返回的路由表字符串变为对象
        commit('SET_BP', data.routes.some(e => Array.isArray(e)) ? data.routes.pop() : ['*']) // 将按钮权限列表添加到用户信息中
        const { routes, name, avatar, season_list } = data
        if (!routes || routes.length <= 0) {
          reject('路由表必须是个数组')
        }
        season_list.sort((a, b) => b.season - a.season)
        season_list.forEach(e => {
          e.name = `第${numberToChinese(e.season)}季卖货争霸赛`
        })
        commit('SET_ROUTES', routes) // 添加路由表至 vuex
        commit('SET_NAME', name) // 添加用户名至 vuex
        commit('SET_AVATAR', avatar) // 添加用户头像至 vuex
        commit('SET_SEASON_LIST', season_list) // 添加赛季信息至 vuex
        team_all({ season: season_list[0].season }).then(res => { // 获取战区列表
          res.data.list.sort((a, b) => a.war_name.charCodeAt() - b.war_name.charCodeAt())
          commit('SET_TEAM_LIST', res.data.list) // 添加团队信息至 vuex
        })
        resolve(data)
      }).catch(error => reject(error))
    })
  },
  logout({ commit, state, dispatch }) { // 退出登录
    return new Promise((resolve, reject) => {
      commit('SET_TOKEN', '')
      commit('SET_ROUTES', [])
      removeToken()
      resetRouter()
      dispatch('tagsView/delAllViews', null, { root: true })
      resolve()
    })
  },
  // remove token
  resetToken({ commit }) {
    return new Promise(resolve => {
      commit('SET_TOKEN', '')
      removeToken()
      resolve()
    })
  },
  // dynamically modify permissions
  changeRoles({ commit, dispatch }, role) {
    return new Promise(async resolve => {
      const token = role + '-token'
      commit('SET_TOKEN', token)
      setToken(token)
      const { roles } = await dispatch('getInfo')
      resetRouter()
      const accessRoutes = await dispatch('permission/generateRoutes', roles, { root: true })
      router.addRoutes(accessRoutes)
      dispatch('tagsView/delAllViews', null, { root: true })
      resolve()
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
